@@ -16,7 +16,7 @@ testthat::test_that('obtainGBIF can correctly obtain observations of species in
     map <- st_transform(map, proj)
   }
 
-  species <- obtainGBIF(query = speciesIn,
+  species <- obtainGBIF(query = speciesIn, filterDistance = 0,
                         datasettype = 'PO', country = 'NO',
                         coordinateUncertaintyInMeters = 50,
                         geometry = map, projection = proj)
@@ -25,7 +25,7 @@ testthat::test_that('obtainGBIF can correctly obtain observations of species in
   expect_true(all(species$coordinateUncertaintyInMeters <= 50))
   expect_identical(st_crs(species)[2], st_crs(proj)[2])
 
-  speciesPA <- obtainGBIF(query = speciesIn,
+  speciesPA <- obtainGBIF(query = speciesIn, filterDistance = 0,
                           datasettype = 'PA',country = 'NO',
                           geometry = map, projection = proj)
 
@@ -34,15 +34,29 @@ testthat::test_that('obtainGBIF can correctly obtain observations of species in
   speciesIn2 <- 'Ceratotherium simum'
 
   expect_error(obtainGBIF(query = speciesIn2, datasettype = 'PA',
-                          country = 'NO',
+                          country = 'NO', filterDistance = 0,
                           geometry = map, projection = proj), 'Species provided not available in specified area.')
 
   ##Multiple years
 
-  speciesTime <- obtainGBIF(query = speciesIn,
+  speciesTime <- obtainGBIF(query = speciesIn, filterDistance = 0,
                             datasettype = 'PO',country = 'NO',
                             geometry = map, projection = proj, year = 2010:2012)
 
   expect_setequal(unique(speciesTime$year), c(2010, 2011, 2012))
 
+
+  ##Test filter distance
+
+  speciesFilter <- obtainGBIF(query = speciesIn, filterDistance = 10,
+                            datasettype = 'PO',country = 'NO',
+                            geometry = map, projection = proj, year = 2010:2012)
+
+  dists <- units::set_units(st_distance(speciesFilter, st_cast(map,"MULTILINESTRING")), km)
+  expect_true(all(as.vector(dists) > 10))
+
+  expect_warning(obtainGBIF(query = speciesIn, filterDistance = 1e8,
+                            datasettype = 'PO',country = 'NO',
+                            geometry = map, projection = proj, year = 2010:2012), 'Fraxinus excelsior provided no occurrence reccords over the specified region.')
+
 })
